@@ -12,6 +12,7 @@ import zlib
 
 import _damo_fmt_str
 import _damon
+import _damon_args
 import damo_report_access
 
 PERF = 'perf'
@@ -135,30 +136,41 @@ def merge_records(records):
 def regions_intersect(r1, r2):
     return not (r1.end <= r2.start or r2.end <= r1.start)
 
+def sz_filter_passed_for_new_size(region, new_size):
+    if region.sz_filter_passed is None:
+        return None
+    filter_pass_ratio = region.sz_filter_passed / region.size()
+    return int(filter_pass_ratio * new_size)
+
 def add_region(regions, region, nr_acc_to_add):
     for r in regions:
-        if regions_intersect(r, region):
-            if not r in nr_acc_to_add:
-                nr_acc_to_add[r] = 0
-            nr_acc_to_add[r] = max(nr_acc_to_add[r],
-                    region.nr_accesses.samples)
+        if not regions_intersect(r, region):
+            continue
+        if not r in nr_acc_to_add:
+            nr_acc_to_add[r] = 0
+        nr_acc_to_add[r] = max(nr_acc_to_add[r],
+                region.nr_accesses.samples)
 
-            new_regions = []
-            if region.start < r.start:
-                new_regions.append(_damon.DamonRegion(
-                    region.start, r.start,
+        new_regions = []
+        if region.start < r.start:
+            new_regions.append(_damon.DamonRegion(
+                region.start, r.start,
+                region.nr_accesses.samples, _damon.unit_samples,
+                region.age.aggr_intervals, _damon.unit_aggr_intervals,
+                sz_filter_passed_for_new_size(
+                    region, r.start - region.start)))
+        if r.end < region.end:
+            new_regions.append(_damon.DamonRegion(
+                    r.end, region.end,
                     region.nr_accesses.samples, _damon.unit_samples,
-                    region.age.aggr_intervals, _damon.unit_aggr_intervals))
-            if r.end < region.end:
-                new_regions.append(_damon.DamonRegion(
-                        r.end, region.end,
-                        region.nr_accesses.samples, _damon.unit_samples,
-                        region.age.aggr_intervals,
-                        _damon.unit_aggr_intervals))
+                    region.age.aggr_intervals,
+                    _damon.unit_aggr_intervals,
+                    sz_filter_passed_for_new_size(
+                        region, region.end - r.end)))
 
-            for new_r in new_regions:
-                add_region(regions, new_r, nr_acc_to_add)
-            return
+        for new_r in new_regions:
+            add_region(regions, new_r, nr_acc_to_add)
+        return
     regions.append(region)
 
 def aggregate_snapshots(snapshots):
@@ -1159,6 +1171,7 @@ def tried_regions_to_snapshot(scheme, intervals, merge_regions):
                     last_region.nr_accesses == tried_region.nr_accesses and
                     last_region.age == tried_region.age):
                 last_region.end = tried_region.end
+                last_region.sz_filter_passed += tried_region.sz_filter_passed
                 continue
         regions.append(tried_region)
     if scheme.tried_bytes is not None:
@@ -1314,7 +1327,7 @@ def get_snapshot_records_for_schemes(idxs, total_sz_only, merge_regions):
         return None, 'no kdamond running'
 
     return update_get_snapshot_records(running_kdamond_idxs, idxs,
-            total_sz_only, merge_regions, None)
+            total_sz_only, merge_regions)
 
 def region_of_pattern(region, pattern, record_intervals):
     sz_bytes = pattern.sz_bytes
@@ -1396,6 +1409,19 @@ def filter_records_by_snapshot_time(records, time_ranges):
                 filtered_snapshots.append(snapshot)
         record.snapshots = filtered_snapshots
 
+def filter_records_by_snapshot_indices(records, index_ranges):
+    for record in records:
+        filtered_snapshots = []
+        for idx, snapshot in enumerate(record.snapshots):
+            filter_out = True
+            for start_idx, end_idx in index_ranges:
+                if start_idx <= idx and idx <= end_idx:
+                    filter_out = False
+                    break
+            if filter_out is False:
+                filtered_snapshots.append(snapshot)
+        record.snapshots = filtered_snapshots
+
 def filter_records_by_temperature(records, temperature_ranges,
                                   temperature_weights):
     for record in records:
@@ -1424,10 +1450,11 @@ def get_snapshot_records_of(request):
                     filters.append(_damon.DamosFilter(
                         'addr', False,
                         address_range=_damon.DamonRegion(start, end)))
+            if request.record_filter.damos_filters is not None:
+                filters += request.record_filter.damos_filters
             monitor_scheme = _damon.Damos(
                     access_pattern=request.record_filter.access_pattern,
                     filters=filters)
-
         else:
             monitor_scheme = _damon.Damos()
 
@@ -1444,17 +1471,22 @@ class RecordFilter:
     address_ranges = None
     snapshot_sz_ranges = None
     snapshot_time_ranges = None
+    snapshot_index_ranges = None
     temperature_ranges = None
     temperature_weights = None
+    damos_filters = None
 
     def __init__(self, access_pattern, address_ranges, snapshot_sz_ranges,
-                 snapshot_time_ranges, temperature_ranges, temperature_weights):
+                 snapshot_time_ranges, snapshot_index_ranges,
+                 temperature_ranges, temperature_weights, damos_filters):
         self.access_pattern = access_pattern
         self.address_ranges = address_ranges
         self.snapshot_sz_ranges = snapshot_sz_ranges
         self.snapshot_time_ranges = snapshot_time_ranges
+        self.snapshot_index_ranges = snapshot_index_ranges
         self.temperature_ranges = temperature_ranges
         self.temperature_weights = temperature_weights
+        self.damos_filters = damos_filters
 
     def to_kvpairs(self, raw):
         kvpairs = {'access_pattern': self.access_pattern.to_kvpairs(raw)}
@@ -1474,8 +1506,11 @@ class RecordFilter:
                      _damo_fmt_str.format_sz(end, raw)]
                     for start, end in self.snapshot_sz_ranges]
         kvpairs['snapshot_sz_ranges'] = snapshot_sz_ranges
+        kvpairs['snapshot_time_ranges'] = self.snapshot_time_ranges
+        kvpairs['snapshot_index_ranges'] = self.snapshot_index_ranges
         kvpairs['temperature_ranges'] = self.temperature_ranges
         kvpairs['temperature_weights'] = self.temperature_weights
+        kvpairs['damos_filters'] = [f.to_kvpairs() for f in self.damos_filters]
         return kvpairs
 
     def filter_records(self, records):
@@ -1488,6 +1523,9 @@ class RecordFilter:
             filter_records_by_snapshot_sz(records, self.snapshot_sz_ranges)
         if self.snapshot_time_ranges is not None:
             filter_records_by_snapshot_time(records, self.snapshot_time_ranges)
+        if self.snapshot_index_ranges is not None:
+            filter_records_by_snapshot_indices(records,
+                                               self.snapshot_index_ranges)
         if self.temperature_ranges is not None:
             filter_records_by_temperature(records, self.temperature_ranges,
                                           self.temperature_weights)
@@ -1530,7 +1568,8 @@ def get_records(tried_regions_of=None, record_file=None, record_filter=None,
     if record_filter:
         filter_copy = copy.deepcopy(record_filter)
     else:
-        filter_copy = RecordFilter(None, None, None, None, None, None)
+        filter_copy = RecordFilter(None, None, None, None, None, None, None,
+                                   None)
 
     if request.record_file is None:
         records, err = get_snapshot_records_of(request)
@@ -1594,15 +1633,29 @@ def args_to_filter(args):
                 [_damo_fmt_str.text_to_ns(s), _damo_fmt_str.text_to_ns(e)]
                 for s, e in args.snapshot_time]
 
+    snapshot_index_ranges = None
+    if args.snapshot_idx is not None:
+        snapshot_index_ranges = [
+                [_damo_fmt_str.text_to_nr(s), _damo_fmt_str.text_to_nr(e)]
+                for s, e in args.snapshot_idx]
+
+    # maybe this is called from damo_report_access
     if hasattr(args, 'temperature_weights'):
         temperature_weights = args.temperature_weights
     else:
         # ignore size
         temperature_weights = [0, 100, 100]
 
+    damos_filters, err = _damon_args.damos_options_to_filters(
+            args.damos_filter)
+    if err is not None:
+        damos_filters = []
+
     return RecordFilter(access_pattern, addr_range,
                         snapshot_sz_ranges, snapshot_time,
-                        args.temperature, temperature_weights), None
+                        snapshot_index_ranges,
+                        args.temperature, temperature_weights,
+                        damos_filters), None
 
 def set_filter_argparser(parser):
     parser.add_argument('--sz_region', metavar=('<min>', '<max>'), nargs=2,
@@ -1625,7 +1678,15 @@ def set_filter_argparser(parser):
             '--snapshot_time', metavar=('<start (ns)>', '<end (ns)>'), nargs=2,
             action='append',
             help='show snapshots generated in these time intervals')
+    parser.add_argument(
+            '--snapshot_idx', metavar=('<start>', '<end>'), nargs=2,
+            action='append',
+            help='show snapshots of these indices range')
     parser.add_argument(
             '--temperature', metavar=('<min>', '<max>'), nargs=2, type=int,
             action='append',
             help='min/max temperature of regions to show')
+    parser.add_argument(
+            '--damos_filter', nargs='+', action='append', default=[],
+            metavar='<filter argument>',
+            help='damos filter (type, matching, and optional arguments)')
