@@ -555,14 +555,18 @@ def files_content_to_damos_stats(files_content):
             int(files_content['sz_tried']),
             int(files_content['nr_applied']),
             int(files_content['sz_applied']),
+            int(files_content['sz_ops_filter_passed']
+                if 'sz_ops_filter_passed' in files_content else 0),
             int(files_content['qt_exceeds']))
 
 def files_content_to_damos_tried_regions(files_content):
     return [_damon.DamonRegion(
             int(kv['start']), int(kv['end']),
             int(kv['nr_accesses']), _damon.unit_samples,
-            int(kv['age']), _damon.unit_aggr_intervals)
-            for kv in number_sorted_dirs(files_content)]
+            int(kv['age']), _damon.unit_aggr_intervals,
+            int(kv['sz_filter_passed'])
+            if 'sz_filter_passed' in kv else None,
+            ) for kv in number_sorted_dirs(files_content)]
 
 def files_content_to_scheme(files_content):
     return _damon.Damos(
@@ -726,12 +730,8 @@ def scheme_tried_regions_dir_of(kdamond_idx, context_idx, scheme_idx):
             'tried_regions')
 
 def infer_damon_version():
-    version = '<5.15'
     orig_kdamonds = current_kdamonds()
 
-    if os.path.isfile(os.path.join(scheme_dir_of(0, 0, 0), 'target_nid')):
-        return '>6.10'
-
     kdamonds = [
             _damon.Kdamond(
                 state=None, pid=None, contexts=[
@@ -742,8 +742,15 @@ def infer_damon_version():
                                 )])])]
     err = stage_kdamonds(kdamonds)
     if err is None:
+        if os.path.isfile(os.path.join(scheme_dir_of(0, 0, 0), 'stats',
+                                       'sz_ops_filter_passed')):
+            version = '>v6.13'
+        elif os.path.isfile(os.path.join(scheme_dir_of(0, 0, 0), 'target_nid')):
+            version = '>=v6.11'
+        else:
+            version = 'v6.10'
         err = stage_kdamonds(orig_kdamonds)
-        return '6.10'
+        return version
 
     kdamonds[0].contexts[0].schemes[0].filters = []
     err = stage_kdamonds(kdamonds)
@@ -839,6 +846,11 @@ def update_supported_features():
     if os.path.isfile(os.path.join(scheme_dir_of(0, 0, 0), 'target_nid')):
         feature_supports['schemes_migrate'] = True
 
+    if os.path.isfile(
+            os.path.join(scheme_dir_of(0, 0, 0),
+                         'stats', 'sz_ops_filter_passed')):
+        feature_supports['sz_ops_filter_passed'] = True
+
     avail_ops, err = _avail_ops()
     if err == None:
         for ops in ['vaddr', 'paddr', 'fvaddr']:
