@@ -26,6 +26,9 @@ def main(args):
         print(json.dumps(feature_supports, indent=4, sort_keys=True))
 
     if args.infer_version:
+        if _damon._damon_fs is not _damon_sysfs:
+            print('Version inferrence is unavailable')
+            exit(1)
         print('Seems the version of DAMON is %s' %
               _damon_sysfs.infer_damon_version())
 
