@@ -144,6 +144,16 @@ region_formatters = [
             lambda index, region, fmt:
             temperature_str(region, fmt.raw_number, fmt),
             'access temperature of the region'),
+        Formatter(
+            '<filters passed bytes>',
+            lambda index, region, fmt:
+            _damo_fmt_str.format_sz(region.sz_filter_passed, fmt.raw_number)
+            if region.sz_filter_passed is not None else 'N/A',
+            'bytes of the region that passed DAMOS filters'),
+        Formatter(
+            '<filters passsed type>',
+            lambda index, region, fmt: fmt.region_filters_pass_type,
+            'type of <filters passed bytes> memory'),
         Formatter(
             '<box>',
             lambda index, region, fmt:
@@ -795,6 +805,8 @@ class RecordsVisualizationFormat:
     json = None
     raw = None
 
+    region_filters_pass_type = None
+
     @classmethod
     def from_args(cls, args):
         self = cls()
@@ -819,6 +831,11 @@ class RecordsVisualizationFormat:
         self.raw_number = args.raw_number
         self.json = args.json
         self.raw = args.raw_form
+        type_str, err = _damon_args.passed_bytes_type_str(args.damos_filter)
+        if err is not None:
+            self.region_filters_pass_type = err
+        else:
+            self.region_filters_pass_type = type_str
         return self
 
     def total_sz_only(self):
@@ -939,6 +956,11 @@ def set_formats(args):
             args.format_snapshot_tail = ('%s\n<region box description>' %
                     args.format_record_tail)
 
+    if args.format_region == default_region_format:
+        if args.tried_regions_of or args.damos_filter:
+            args.format_region += ' %s %s' % (
+                    '<filters passsed type>', '<filters passed bytes>')
+
     return RecordsVisualizationFormat.from_args(args)
 
 def handle_ls_keywords(args):
@@ -1090,8 +1112,11 @@ def add_fmt_args(parser, hide_help=False):
             '--min_chars_for', nargs=2,
             metavar=('<keyword>', '<number>'), action='append',
             default=[['<index>', 3],
-                ['<start address>', 12],['<end address>', 11],
-                ['<size>', 11], ['<access rate>', 5]],
+                     ['<start address>', 12],['<end address>', 11],
+                     ['<size>', 11], ['<access rate>', 5],
+                     ['<age>', 13],
+                     ['<filters passed type>', 10],
+                     ],
             help='minimum character for each keyword of the format'
             if not hide_help else argparse.SUPPRESS)
     parser.add_argument('--region_box', action='store_true',
